pub struct FingerprintHistogram { /* private fields */ }Expand description
given a collection of busfiles, FingerPrintHistogram keeps track of the number of times we see a molecule (CB/UMI/gene) in a particular distribution across the busfiles. Instead recording individual CUGs, we aggregate all the ones having the same fingerprint across samples, i.e. we create a histogram of fingerprints
Implementations
Sourceimpl FingerprintHistogram
impl FingerprintHistogram
pub fn get_samplenames(&self) -> Vec<String>
pub fn get_histogram(&self) -> HashMap<Vec<u32>, usize>
pub fn new(sample_order: &[String]) -> Self
Sourcepub fn add(
&mut self,
record_dict: HashMap<String, Vec<BusRecord>>,
ecmapper_dict: &HashMap<String, &Ec2GeneMapper>,
)
pub fn add( &mut self, record_dict: HashMap<String, Vec<BusRecord>>, ecmapper_dict: &HashMap<String, &Ec2GeneMapper>, )
adds a CUG (observed over several busfiles) into the histogram
Sourcepub fn to_dataframe(&self) -> DataFrame
pub fn to_dataframe(&self) -> DataFrame
turn the fingerprint histgram into a polars Dataframe
Sourcepub fn estimate_sihr(&self) -> f64
pub fn estimate_sihr(&self) -> f64
Estimate SIHR from the histogram via binomial regression TODO: the paper suggests to filter some values:
- remove samples (rows over r) with less than 10 observations (m_r <10)
- remove samples with r>25